@@ -11,8 +11,7 @@
 ;; URL: http://github.com/nonsequitur/inf-ruby
 ;; Created: 8 April 1998
 ;; Keywords: languages ruby
-;; Package-Version: 2.9.0
-;; Package-Revision: b8076aad10df
+;; Version: 2.9.0
 ;; Package-Requires: ((emacs "26.1"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -166,24 +165,24 @@ commands as `ruby-send-last-stmt' or `ruby-switch-to-inf'."
       "\\(^(rdb:1) *\\)"                  ; Debugger
       "\\(^(rdbg[^)]*) *\\)"              ; Ruby Debug Gem
       "\\(^(byebug) *\\)"                 ; byebug
-      "\\(^[a-z0-9-_]+([a-z0-9-_]+)%s *\\)" ; Rails 7+: project name and environment
-      "\\(^\\(irb([^)]+)"                 ; IRB default
+      "\\(^\\([a-z0-9-_]+([a-z0-9-_]+)"   ; Rails 7+: project name and environment
+      "irb([^)]+)"                        ; IRB default
       "\\([[0-9]+] \\)?[Pp]ry ?([^)]+)"   ; Pry
       "\\(jruby-\\|JRUBY-\\)?[1-9]\\.[0-9]\\(\\.[0-9]+\\)*\\(-?p?[0-9]+\\)?" ; RVM
       "^rbx-head\\)")                     ; RVM continued
     "\\|")
-   ;; Statement and nesting counters, common to the last four.
+   ;; Statement and nesting counters, common to the last five.
    " ?[0-9:]* ?%s *\\)")
   "Format string for the prompt regexp pattern.
 Two placeholders: first char in the Simple prompt, and the last
 graphical char in all other prompts.")
 
-(defvar inf-ruby-first-prompt-pattern (format inf-ruby-prompt-format ">" ">" ">")
+(defvar inf-ruby-first-prompt-pattern (format inf-ruby-prompt-format ">" ">")
   "First prompt regex pattern of Ruby interpreter.")
 
 (defvar inf-ruby-prompt-pattern
   (let ((delims "[\]>*\"'/`]"))
-    (format inf-ruby-prompt-format "[?>]" delims delims))
+    (format inf-ruby-prompt-format "[?>]" delims))
   "Prompt regex pattern of Ruby interpreter.")
 
 (defvar inf-ruby-mode-hook nil
